@@ -31,6 +31,10 @@ MISSING_LIMITS = Limits()
 DEFAULT_LIMITS = Limits(depth=20, selections=None, complexity=100)
 
 
+class EarlyStop(Exception):
+    pass
+
+
 class ResourceLimitReached(GraphQLError):
     pass
 
@@ -45,3 +49,9 @@ class SelectionsLimitReached(ResourceLimitReached):
 
 class ComplexityLimitReached(ResourceLimitReached):
     pass
+
+
+# the worst problem for calculations is edges/node as it increases the
+# complexity and depth count by 2
+# the other parts does not affect the calculations by these magnitudes
+default_path_ignore_pattern = "edges/node$"
